/*
   Copyright (C) 2007 - 2009 by Roberto García Carvajal <roberpot@gmail.com>
   Part of libglsws (http://magiccards.wordpress.com)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 3
   or at your option any later version.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY.

   See the COPYING file for more details.
*/

#include <GL/gl.h>
#include "c_oventana.h"

/*******************************************************************************
*
* Constructor
* Recibe un entero sin signo de 32 bits a modo de registro de banderas.
* Inicializa los datos.
*
*******************************************************************************/
c_ocasillero::c_ocasillero(GLuint rbe)
{
 _o_x = 10;
 _o_y = 10;
 _o_ancho = 10;
 _o_alto = 10;
 _RBE = rbe;
 _o_colorf[0] = 0.70;
 _o_colorf[1] = 0.70;
 _o_colorf[2] = 0.70;
 _o_colorb[0] = 0.00;
 _o_colorb[1] = 0.00;
 _o_colorb[2] = 0.00;
 _o_tipo = O_T_CASILLERO;
 _seleccionado = false;
 //FIX-ME faltan datos.
}

/*******************************************************************************
*
* Método dibujar.
* Recibe dos flotantes x e y.
* Renderiza el texto.
*
*******************************************************************************/
void c_ocasillero::dibujar(GLfloat x,GLfloat y)
{
 // Lo hago en otra matriz sobre la pila.
 glPushMatrix();
 glTranslatef(x+_o_x,y+_o_y,0.0);
 // Si es visible...
 if(_RBE & O_VISIBLE)
 {
  // Elijo el color
  glColor3fv(_o_colorf);
  glBegin(GL_QUADS);
   glVertex2f(0, 0);
   glVertex2f(0, _o_alto);
   glVertex2f(_o_ancho, _o_alto);
   glVertex2f(_o_ancho, 0);
  glEnd();
  glColor3fv(_o_colorb);
  glBegin(GL_LINE_LOOP);
   glVertex2f(0, 0);
   glVertex2f(0, _o_alto);
   glVertex2f(_o_ancho, _o_alto);
   glVertex2f(_o_ancho, 0);
  glEnd();
  // Si está seleccionado dibujo la cruz.
  if(_seleccionado)
  {
   glBegin(GL_LINES);
    glVertex2f(0, 0);
    glVertex2f(_o_ancho, _o_alto);
    glVertex2f(0, _o_alto);
    glVertex2f(_o_ancho, 0);
   glEnd();
  }
 }
 glPopMatrix();
}

/*******************************************************************************
*
* Método ejecutar_acciones (Sobrecargado).
* Recibe dos flotantes x e y.
* Cambia el estado de seleccionado a no seleccionado y viceversa.
*
*******************************************************************************/
void c_ocasillero::ejecutar_acciones(GLfloat x, GLfloat y)
{
 if(_seleccionado)
  _seleccionado = false;
 else
  _seleccionado = true;
}

/*******************************************************************************
*
* Método cargar.
* Recibe un dato.
* Procesa el dato.
*
*******************************************************************************/
void c_ocasillero::cargar(c_dato d)
{
 if(d.t_dato() == _T_DATO_BOOL)
 {
  _seleccionado = d.b();
 }
}

/*******************************************************************************
*
* Método guardar.
* Devuelve el dato asociado.
*
*******************************************************************************/
c_dato c_ocasillero::guardar()
{
 c_dato d;
 d.setb(_seleccionado);
 return d;
}
/*******************************************************************************
*
* Destructor.
*
*******************************************************************************/
c_ocasillero::~c_ocasillero()
{
}
