/*
   Copyright (C) 2007 - 2009 by Roberto García Carvajal <roberpot@gmail.com>
   Part of libglsws (http://magiccards.wordpress.com)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 3
   or at your option any later version.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY.

   See the COPYING file for more details.
*/

#include <GL/gl.h>
#include <map>
#include "c_oventana.h"
#include "c_esdatos.h"

#ifndef _C_VENTANA_
#define _C_VENTANA_

using namespace std;

/*******************************************************************************
*
* Definiciones de las banderas de estado de una ventana.
*
*******************************************************************************/
#define V_VISIBLE     0x01
#define V_MOVIL       0x02
#define V_REDIMENSION 0x04
#define V_TEXTURADO   0x08

/*******************************************************************************
*
* Clase c_ventana
*
* Una ventana del sistema de ventanas.
*
*******************************************************************************/
class c_ventana
{
 public:
  /// Constructor.
  c_ventana(GLuint rbe = 0 | V_VISIBLE | V_MOVIL);
  /// Para establecer la posición horizontal.
  void x(GLfloat x);
  /// Para establecer la posición vertical.
  void y(GLfloat y);
  /// Para conocer la posición horizontal.
  GLfloat x() { return _x; }
  /// Para conocer la posición vertical.
  GLfloat y() { return _y; }
  /// Para establecer el ancho.
  void ancho(GLfloat a);
  /// Para establecer el alto.
  void alto(GLfloat a);
  /// Para establecer el color del fondo.
  void colorf(GLfloat c[3]);
  /// Para establecer el color del borde.
  void colorb(GLfloat c[3]);
  /// Para asignarle una textura.
  void textura(GLuint t) { _textura = t; }
  /// Para establecer estados.
  void set(GLuint BE);
  /// Para retirar estados.
  void unset(GLuint BE);
  /// Para conocer el estado de la ventana.
  GLuint estado() { return _RBE; }
  /// Para cargar un conjunto de datos.
  void cargar(c_datos d);
  /// Para saber si se hace click encima.
  std::pair<bool,bool> click(GLfloat x,GLfloat y);
  /// Para renderizarla.
  void dibujar();
  /// Para añadir un nuevo objeto.
  void nobjeto(GLint id,c_oventana * obj);
  /// Para eliminar un objeto.
  void eobjeto(GLint id);
  /// Para obtener un objeto.
  c_oventana * objeto(GLint id) { return _objetos[id]; }
  /// Para añadir un carácter a un objeto.
  void recogercaracter(GLubyte c);
  /// Para borrar un carácter de un objeto.
  void borrarcaracter();
  /// Devuelve las acciones del objeto enfocado asociadas al evento.
  vector<c_accion> acciones(GLuint evento);
  /// Devuelve los datos de la ventana.
  c_datos datos();
 private:
  GLuint _RBE,           /// Registro de banderas de estado.
         _nobjetos,      /// Número de objetos de la ventana.
         _textura;     /// Textura del objeto.
  GLint _id_foco;        /// Objeto actualmente enfocado.
  GLfloat _colorf[3],  /// Color del fondo.
          _colorb[3],  /// Color del borde.
          _ancho,      /// Ancho de la ventana.
          _alto,       /// Alto de la ventana.
          _x,          /// Posición horizontal.
          _y;          /// Posición vertical.
  map<GLint,c_oventana *> _objetos; /// Objetos de la ventana.
};

#endif
